pub struct RetentionConfiguration {
pub group_message_seconds: u64,
pub welcome_seconds: u64,
pub key_package_seconds: u64,
}Expand description
How long the deployment keeps each payload kind, in seconds.
Fields
group_message_seconds: u64welcome_seconds: u64key_package_seconds: u64Trait Implementations
Sourceimpl Clone for RetentionConfiguration
impl Clone for RetentionConfiguration
Sourcefn clone(&self) -> RetentionConfiguration
fn clone(&self) -> RetentionConfiguration
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RetentionConfiguration
impl Debug for RetentionConfiguration
Sourceimpl Default for RetentionConfiguration
impl Default for RetentionConfiguration
Sourceimpl PartialEq for RetentionConfiguration
impl PartialEq for RetentionConfiguration
Sourcefn eq(&self, other: &RetentionConfiguration) -> bool
fn eq(&self, other: &RetentionConfiguration) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for RetentionConfiguration
impl StructuralPartialEq for RetentionConfiguration